==> ejc-sale-impl-3.0.0-20220502.092958-73-sources.jar: com/ejianc/business/sale/service/impl/OpeninvoiceBpmServiceImpl.java <==
package com.ejianc.business.sale.service.impl;

import com.ejianc.business.sale.bean.*;
import com.ejianc.business.sale.service.IOpeninvoiceService;
import com.ejianc.business.sale.service.IOpeninvoicedetialService;
import com.ejianc.business.sale.service.ISignfreightService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

@Service("openinvoice") 
public class OpeninvoiceBpmServiceImpl implements ICommonBusinessService {

	private Logger logger = LoggerFactory.getLogger(this.getClass());
	@Autowired
	private IOpeninvoiceService openinvoiceService;
	@Autowired
	private ISignfreightService signfreightService;
	@Autowired
	private IOpeninvoicedetialService openinvoicedetialService;
	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		logger.info("---------进来啦--------");
		OpeninvoiceEntity openinvoiceEntity = openinvoiceService.selectById(billId);
		if(openinvoiceEntity.getOpeninvoicedetialList() != null){
			logger.info("---------不为空--------");
			for(OpeninvoicedetialEntity openinvoicedetialEntity : openinvoiceEntity.getOpeninvoicedetialList()){
				SignfreightEntity signfreightEntity = signfreightService.getById(openinvoicedetialEntity.getSignfreightId());
				signfreightEntity.setPaymentMoney(openinvoicedetialEntity.getDistributionMoney());
				signfreightEntity.setNotPaymentMoney(signfreightEntity.getNotOpeninvoiceMoney().subtract(openinvoicedetialEntity.getDistributionMoney()));
				if(signfreightEntity.getNotPaymentMoney().doubleValue() != 0.00){
					signfreightEntity.setOpeninvoiceStatus(2);
				}else{
					signfreightEntity.setOpeninvoiceStatus(0);
				}
				signfreightService.updateById(signfreightEntity);
				openinvoicedetialEntity.setReimbursedMoney(openinvoicedetialEntity.getDistributionMoney());
				openinvoicedetialEntity.setNotReimbursedMoney(openinvoicedetialEntity.getOpenInvoiceMoney().subtract(openinvoicedetialEntity.getDistributionMoney()));
				logger.info("---------已修改--------");
				openinvoicedetialService.updateById(openinvoicedetialEntity);
			}
		}
		logger.info("---------结束--------");
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

}

==> ejc-sale-impl-3.0.0-20220818.035037-208-sources.jar: com/ejianc/business/sale/service/impl/OpeninvoiceBpmServiceImpl.java <==
package com.ejianc.business.sale.service.impl;

import com.ejianc.business.sale.bean.*;
import com.ejianc.business.sale.service.IOpeninvoiceService;
import com.ejianc.business.sale.service.IOpeninvoicedetialService;
import com.ejianc.business.sale.service.ISignfreightService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;

@Service("openinvoice") 
public class OpeninvoiceBpmServiceImpl implements ICommonBusinessService {

	private Logger logger = LoggerFactory.getLogger(this.getClass());
	@Autowired
	private IOpeninvoiceService openinvoiceService;
	@Autowired
	private ISignfreightService signfreightService;
	@Autowired
	private IOpeninvoicedetialService openinvoicedetialService;
	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {
		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		logger.info("---------进来啦--------");
		OpeninvoiceEntity openinvoiceEntity = openinvoiceService.selectById(billId);
		if(openinvoiceEntity.getOpeninvoicedetialList() != null){
			logger.info("---------不为空--------");
			for(OpeninvoicedetialEntity openinvoicedetialEntity : openinvoiceEntity.getOpeninvoicedetialList()){
				SignfreightEntity signfreightEntity = signfreightService.getById(openinvoicedetialEntity.getSignfreightId());
				signfreightEntity.setOpeninvoiceMoney(openinvoicedetialEntity.getDistributionMoney().add(signfreightEntity.getOpeninvoiceMoney()));
				signfreightEntity.setNotOpeninvoiceMoney(signfreightEntity.getNotOpeninvoiceMoney().subtract(openinvoicedetialEntity.getDistributionMoney()));
				if(signfreightEntity.getNotOpeninvoiceMoney().doubleValue() != 0.00){
					signfreightEntity.setOpeninvoiceStatus(2);
				}else{
					signfreightEntity.setOpeninvoiceStatus(0);
				}
				signfreightService.updateById(signfreightEntity);
				openinvoicedetialEntity.setReimbursedMoney(openinvoicedetialEntity.getDistributionMoney());
				openinvoicedetialEntity.setNotReimbursedMoney(openinvoicedetialEntity.getOpenInvoiceMoney().subtract(openinvoicedetialEntity.getDistributionMoney().add(openinvoicedetialEntity.getOtherReimbursedMoney())));
				logger.info("---------已修改--------");
				openinvoicedetialService.updateById(openinvoicedetialEntity);
			}
		}
		logger.info("---------结束--------");
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

}
